#!/usr/bin/env python

from WebStack.Generic import ContentType
from WebStack.Resources.LoginRedirect import LoginRedirectResource, LoginRedirectAuthenticator
from WebStack.Resources.Login import LoginResource, LoginAuthenticator
from WebStack.Resources.ResourceMap import MapResource
from Simple import SimpleResource

def get_site_map(app_url, login_url, secret_key):

    """
    Resource a resource for the site having the given 'app_url' and 'login_url',
    using the given 'secret_key' for authentication tokens.
    """

    simple = LoginRedirectResource(
        login_url=login_url,
        app_url=app_url,
        resource=SimpleResource(),
        authenticator=LoginRedirectAuthenticator(secret_key=secret_key)
        )

    simple.anonymous_parameter_name = "anonymous"
    simple.logout_parameter_name = "logout"

    return MapResource({
        "simple" : simple,
        "login" :
            LoginResource(
                LoginAuthenticator(
                    secret_key=secret_key,
                    credentials=(
                        ("badger", "abc"),
                        ("vole", "xyz"),
                    )
                )
            ),
        "" : simple
        })

# vim: tabstop=4 expandtab shiftwidth=4
