#!/usr/bin/env python

from WebStack.Generic import ContentType
from WebStack.Resources.OpenIDRedirect import OpenIDRedirectResource, OpenIDRedirectAuthenticator
from WebStack.Resources.OpenIDInitiation import OpenIDInitiationResource
from WebStack.Resources.ResourceMap import MapResource
from WebStack.Resources.Static import StringResource
from Simple import SimpleResource

def get_site_map(app_url, initiation_url, secret_key):

    """
    Resource a resource for the site having the given 'app_url' and
    'initiation_url', using the given 'secret_key' for authentication tokens.
    """

    return MapResource({
        "simple" :
            OpenIDRedirectResource(
                login_url=initiation_url,
                app_url=app_url,
                resource=SimpleResource(),
                authenticator=OpenIDRedirectAuthenticator(
                    secret_key=secret_key,
                    app_url=app_url
                    ),
                anonymous_parameter_name="anonymous",
                logout_parameter_name="logout"
            ),

        # The "login" is really OpenID initiation.

        "login" : OpenIDInitiationResource(),

        # A root page.

        "" :
            StringResource("""
                <html>
                  <head>
                    <title>Simple Application with OpenID Login</title>
                  </head>
                  <body>
                    <p>Access the application <a href="simple">here</a>.</p>
                  </body>
                </html>
            """, ContentType("text/html"))

        })

# vim: tabstop=4 expandtab shiftwidth=4
